/*
 * Copyright 2018 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.playground;

import javax.annotation.security.PermitAll;
import javax.ejb.Remote;
import javax.ejb.Stateless;
import javax.inject.Inject;

import org.jboss.ejb3.annotation.SecurityDomain;
import org.jboss.logging.Logger;

@Stateless
@Remote(SimpleRemote.class)
@PermitAll
@SecurityDomain("other") // default SecurityDomain of JBoss EAP
public class SimpleRemoteBean implements SimpleRemote {

    @Inject
    Logger logger;

    public String logMessageAndReturnJBossNodeName(String message) {

        String jbossNodeName = System.getProperty("jboss.node.name");

        logger.warn(message);

        return jbossNodeName;

    }

    public String logMessageAndReturnJBossNodeNameWithDelay(String message, long delay) {

        String jbossNodeName = System.getProperty("jboss.node.name");

        logger.warnf("Going to delay the response by %d ms", delay);

        try {
            Thread.sleep(delay);
        } catch (InterruptedException e) {
            logger.error("Got an InterruptedException", e);
        }

        logger.warn(message);
        return jbossNodeName;
    }
}
