/*
 * Copyright 2018 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.playground;

import org.jboss.ejb.client.Affinity;
import org.jboss.ejb.client.EJBClientInterceptor;
import org.jboss.ejb.client.EJBClientInvocationContext;
import org.jboss.ejb.client.NodeAffinity;
import org.jboss.ejb.client.annotation.ClientInterceptorPriority;
import org.jboss.logging.Logger;

@ClientInterceptorPriority(value = ClientInterceptorPriority.JBOSS_AFTER_END + 1)
public class LogJBossNodeNameClientInterceptor implements EJBClientInterceptor {

    private static final Logger logger = Logger.getLogger(LogJBossNodeNameClientInterceptor.class.getSimpleName());

    @Override
    public void handleInvocation(EJBClientInvocationContext context) throws Exception {

        // make the call
        context.sendRequest();

        // log the target
        logger.info(String.format("target host name [%s:%s]", context.getDestination().getHost(),
                context.getDestination().getPort()));

        Affinity targetAffinity = context.getTargetAffinity();
        String targetJBossNodeName;
        if(targetAffinity != null) {
            if (targetAffinity instanceof NodeAffinity) {
                targetJBossNodeName = ((NodeAffinity) targetAffinity).getNodeName();
            } else {
                targetJBossNodeName = targetAffinity.toString();
            }
        }
        else {
            targetJBossNodeName = "unable to determine jboss.node.name";
        }
        logger.info(String.format("target node name [%s]", targetJBossNodeName));
    }

    @Override
    public Object handleInvocationResult(EJBClientInvocationContext context) throws Exception {
        try {
            return context.getResult();
        } finally {
            // at this point all client interceptors have been invoked
        }
    }
}