/*
 * Copyright 2018 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.playground;

import java.util.Random;
import java.util.concurrent.atomic.AtomicInteger;

import org.jboss.ejb.client.ClusterNodeSelector;
import org.jboss.logging.Logger;

public class RoundRobinClusterNodeSelector implements ClusterNodeSelector {

    private static final Logger logger = Logger.getLogger(RoundRobinClusterNodeSelector.class.getSimpleName());
    
    private AtomicInteger counter;
    
    public RoundRobinClusterNodeSelector() 
    {
        final Random random = new Random();
           
        counter = new AtomicInteger(random.nextInt(5)); 
    }

    @Override
    public String selectNode(String clusterName, String[] connectedNodes, String[] availableNodes) 
    {   
        final int length = availableNodes.length;
        
        assert length > 0;
        if (length < 2) {
            return availableNodes[0];
        }
        
        int availbleNodeIndex = Math.floorMod(counter.getAndIncrement(), length);
        
        logger.info(String.format("nodeSelected: %s", availableNodes[availbleNodeIndex]));;
        
        return availableNodes[availbleNodeIndex];
    }
}