/*
 * Copyright 2018 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.playground;

import java.util.Random;
import java.util.concurrent.atomic.AtomicInteger;

import org.jboss.ejb.client.DeploymentNodeSelector;
import org.jboss.logging.Logger;

public class RoundRobinDeploymentNodeSelector implements DeploymentNodeSelector {

    private static final Logger logger = Logger.getLogger(RoundRobinDeploymentNodeSelector.class.getSimpleName());

    private AtomicInteger counter;
    
    public RoundRobinDeploymentNodeSelector() 
    {
        final Random random = new Random();
           
        counter = new AtomicInteger(random.nextInt(5)); 
    }

    @Override
    public String selectNode(String[] eligibleNodes, String appName, String moduleName, String distinctName)
    {
        final int length = eligibleNodes.length; 
        
        assert length > 0;
        if (length < 2) {
            return eligibleNodes[0];
        }
        
        int eligibleNodeIndex = Math.floorMod(counter.getAndIncrement(), length);
        
        logger.info(String.format("nodeSelected: %s", eligibleNodes[eligibleNodeIndex]));;
        
        return eligibleNodes[eligibleNodeIndex]; 
    }
}