/*
 * Copyright 2020 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.playground.client;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.lang.management.ManagementFactory;
import java.lang.management.RuntimeMXBean;
import java.lang.reflect.Field;
import java.util.Properties;

import org.jboss.logging.Logger;

import sun.management.VMManagement;

@SuppressWarnings("restriction")
public class ClientUtilities {

    private static final Logger logger = Logger.getLogger(ClientUtilities.class);

    public static Properties loadProperties(String filename) {

        logger.infof("Loading properties from file: '%s'", filename);

        Properties properties = new Properties();

        try (FileInputStream fis = new FileInputStream(filename)) {
            properties.load(fis);
        } catch (FileNotFoundException fnfe) {
            fnfe.printStackTrace();
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }

        logger.debugf("Properties: %s", properties);
        return properties;
    }

    @SuppressWarnings("unchecked")
    public static <T extends Object> T getSystemPropertyWithDefault(String property, T defaultValue) {

        String propertyString = System.getProperty(property);

        if (propertyString == null || propertyString.equals(String.format("${%s}", property))) {
            return defaultValue;
        }

        if (defaultValue instanceof Long) {
            return (T) Long.valueOf(propertyString);
        } else if (defaultValue instanceof Integer)
            return (T) Integer.valueOf(propertyString);
        else {
            return (T) propertyString;
        }
    }

    public static int getPidOfProcess() {
        int pid = -1;
        try {
            RuntimeMXBean runtime = ManagementFactory.getRuntimeMXBean();
            Field jvm = runtime.getClass().getDeclaredField("jvm");
            jvm.setAccessible(true);
            VMManagement mgmt = (VMManagement) jvm.get(runtime);
            java.lang.reflect.Method pid_method = mgmt.getClass().getDeclaredMethod("getProcessId");
            pid_method.setAccessible(true);
            pid = (Integer) pid_method.invoke(mgmt);
        } catch (Exception e) {
            logger.warn("Unable to obtain the PID of this process.");
        }
        return pid;
    }
}
