#!/bin/bash
set +x

BASE_DIR=`pwd`
LOGGING_PROPERTIES_REPOSITORY="${BASE_DIR}/../playground-clients/ejb/common-client/src/main/resources/logging.properties"
LOGGING_PROPERTIES_SCRIPT="${BASE_DIR}/logging.properties"

WILDFLY_CONFIG_REPOSITORY="${BASE_DIR}/../playground-clients/ejb/ejb-over-http/src/main/resources/wildfly-config.xml"
WILDFLY_CONFIG_SCRIPT="${BASE_DIR}/wildfly-config.xml"

JAVA_OPTS=""

if [ -z "$JBOSS_HOME" ]; then
    echo "JBOSS_HOME must be set...";
    exit 1
fi

if [ ! -f "$BASE_DIR/run-client.sh" ]; then
    echo "This script must be called from inside 'scripts' folder";
    exit 1
fi

clean() {
    echo "removing local 'wildfly-config.xml' and 'logging.properties'"
    rm wildfly-config.xml
    rm logging.properties
    exit
}

usage() {
	echo "usage:"
	echo "run-client.sh [-h (show usage)] [-c (clean)]  [-Dthreads=10] [-Dqueue=10] [-Dinvocations=0] [-Druntime=2000]" 
	echo ""
	echo "With the default values the client is running for 2sec. If -Dinvocations and -Druntime is given both, the client stops once the first limit is reached."
    echo "The client could be stopped at any time gracefully by entering 'x' on the console"
	exit
}

while getopts ":hcd:D:" opt; do
	case ${opt} in
		h )
			usage
			;;
        c )
            clean
            ;;
		d )
			JAVA_OPTS="${JAVA_OPTS} -agentlib:jdwp=transport=dt_socket,address=${OPTARG},server=y,suspend=y"
			;;
		D )
			SYSTEM_PROPERTIES="${SYSTEM_PROPERTIES} -D${OPTARG}"
			;;
		\? ) 
			echo "Invalid Option: -$OPTARG"
			echo ""
			usage
			;;
	esac
done

# prepare local logging properties
if [ ! -f ${LOGGING_PROPERTIES_SCRIPT} ]; then
    cp $LOGGING_PROPERTIES_REPOSITORY $LOGGING_PROPERTIES_SCRIPT
fi

# prepare the wildfly-config.xml
if [ ! -f ${WILDFLY_CONFIG_SCRIPT} ]; then
    cp $WILDFLY_CONFIG_REPOSITORY $WILDFLY_CONFIG_SCRIPT
fi

SYSTEM_PROPERTIES="${SYSTEM_PROPERTIES} -Dlogging.configuration=file://${LOGGING_PROPERTIES_SCRIPT} -Dwildfly.config.url=wildfly-config.xml"


echo "========================================================================="
echo "This client uses the JBoss EJB client libraries from \$JBOSS_HOME in"
echo "  '${JBOSS_HOME}/bin/client'"
echo "This is useful when the client is started against a patched server..."
echo "-------------------------------------------------------------------------"
echo "going to use the Java System Properties:"
echo "${SYSTEM_PROPERTIES}"
echo "========================================================================="

CLASSPATH="${JBOSS_HOME}/bin/client/jboss-client.jar"
CLASSPATH="${CLASSPATH}:${JBOSS_HOME}/bin/client/jboss-cli-client.jar"
CLASSPATH="${CLASSPATH}:${BASE_DIR}/../playground-app/ejb/target/playground-app-ejb.jar"
CLASSPATH="${CLASSPATH}:${BASE_DIR}/../playground-clients/ejb/common-client/target/playground-ejb-clients.jar"
CLASSPATH="${CLASSPATH}:${BASE_DIR}/../playground-clients/ejb/ejb-over-http//target/playground-ejb-clients.jar"

java -cp "${CLASSPATH}" $SYSTEM_PROPERTIES $JAVA_OPTS org.jboss.playground.client.EjbOverHttpClient

exit 0;
