#!/bin/bash

THIS_SCRIPT="${0##*/}"
CLI_SCRIPT="setup-standalone-elytron-only.cli"
PROPERTIES="setup-standalone-elytron-only.properties"
JBOSS_CONFIG_DIR="standalone/configuration"
BASE_STADALONE_XML="standalone.xml"
CUSTOM_STANDALONE_XML="standalone-custom.xml"

ADMIN_USER="admin"
ADMIN_USER_PASSWORD="admin"

APPLICATION_USER="ejb"
APPLICATION_USER_PASSWORD="ejb-123!"
APPLICATION_USER_ROLES="user,admin"

NO_ROLE_USER="norole"
NO_ROLE_USER_PASSWORD="norole"

BASE_DIR=`pwd`

if [ ! -f "${BASE_DIR}/${THIS_SCRIPT}" ]; then
    echo "This script must be called from inside 'playground/scripts' folder";
    exit 1
fi

# https://sookocheff.com/post/bash/parsing-bash-script-arguments-with-shopts/
while getopts ":j:" opt; do
    case ${opt} in
        j ) # process option b
            JBOSS_HOME=$OPTARG
        ;;
        \? )
            echo "Invalid option: $OPTARG" 1>&2
            exit 1
        ;;
        : )
            echo "Invalid option: $OPTARG requires an argument" 1>&2
            exit 1
        ;;
  esac
done

if [ -z "$JBOSS_HOME" ]; then
    echo "JBOSS_HOME must be set...";
    exit 1
fi 

# copy the standalone.xml to use to the custom one...
cp ${JBOSS_HOME}/${JBOSS_CONFIG_DIR}/${BASE_STADALONE_XML} ${JBOSS_HOME}/${JBOSS_CONFIG_DIR}/${CUSTOM_STANDALONE_XML}


ADMIN_USER_SERVER_IDENTITY=`echo ${ADMIN_USER_PASSWORD} | base64`
APPLICATION_USER_SERVER_IDENTITY=`echo ${APPLICATION_USER_PASSWORD} | base64`
NO_ROLE_USER_SERVER_IDENTITY=`echo ${NO_ROLE_USER_PASSWORD} | base64`

# create users
echo "create management user: ${ADMIN_USER}, password: ${ADMIN_USER_PASSWORD}, server-identities: <secret value=\"${ADMIN_USER_SERVER_IDENTITY}\" />"
$JBOSS_HOME/bin/add-user.sh -u ${ADMIN_USER} -p ${ADMIN_USER_PASSWORD} > /dev/null 2>&1

echo "create application user: ${APPLICATION_USER}, password: ${APPLICATION_USER_PASSWORD}, roles: {${APPLICATION_USER_ROLES}},server identities: <secret value=\"${APPLICATION_USER_SERVER_IDENTITY}\" />"
$JBOSS_HOME/bin/add-user.sh -a -u ${APPLICATION_USER} -p ${APPLICATION_USER_PASSWORD} -g ${APPLICATION_USER_ROLES}> /dev/null 2>&1

echo "create application user: ${NO_ROLE_USER}, password: ${NO_ROLE_USER_PASSWORD}, server identities: <secret value=\"${NO_ROLE_USER_SERVER_IDENTITY}\" />"
$JBOSS_HOME/bin/add-user.sh -a -u ${NO_ROLE_USER} -p ${NO_ROLE_USER_PASSWORD}> /dev/null 2>&1


# prepare properties for the CLI script
[ -f ${PROPERTIES} ] && rm ${PROPERTIES}
echo "jboss.home=${JBOSS_HOME}" > ${PROPERTIES}
echo "standalone.xml=${CUSTOM_STANDALONE_XML}" >> ${PROPERTIES}
echo "admin.user.server.identity=${ADMIN_USER_SERVER_IDENTITY}" >> ${PROPERTIES}
echo "application.user.server.identity=${APPLICATION_USER_SERVER_IDENTITY}" >> ${PROPERTIES}

# enable parameter resolving in jboss-cli
sed -i "s/<resolve-parameter-values>false<\/resolve-parameter-values>/\<resolve-parameter-values>true<\/resolve-parameter-values>/" ${JBOSS_HOME}/bin/jboss-cli.xml

$JBOSS_HOME/bin/jboss-cli.sh --file=${CLI_SCRIPT} --properties=${PROPERTIES}
