#!/bin/bash

THIS_SCRIPT="${0##*/}"
CLI_SCRIPT="setup-standalone-ssl.cli"
PROPERTIES="setup-standalone-ssl.properties"

BASE_DIR=`pwd`

if [ ! -f "$BASE_DIR/$THIS_SCRIPT" ]; then
    echo "This script must be called from inside 'playground/scripts' folder";
    exit 1
fi

CREATE_KEYSTORES="0"
PASSWORD="RedHat-123!"
SALT="RH@S4l7."
ITERATION="666"
KEYSTORE_DIR="."
SERVER_KEYSTORE="server.keystore"
SERVER_TRUSTSTORE="server.truststore"
CLIENT_KEYSTORE="client.keystore"
CLIENT_TRUSTSTORE="client.truststore"

# https://sookocheff.com/post/bash/parsing-bash-script-arguments-with-shopts/
while getopts ":cp:j:" opt; do
    case ${opt} in
        c ) # process option e
            CREATE_KEYSTORES="1"
        ;;
        p ) # process option p
            PASSWORD=$OPTARG
        ;;
        j ) # process option b
            JBOSS_HOME=$OPTARG
        ;;
        \? )
            echo "Invalid option: $OPTARG" 1>&2
            exit 1
        ;;
        : )
            echo "Invalid option: $OPTARG requires an argument" 1>&2
            exit 1
        ;;
  esac
done

if [ -z "$JBOSS_HOME" ]; then
    echo "JBOSS_HOME must be set...";
    exit 1
fi 

if [ $CREATE_KEYSTORES == "1" ]; then

    # create and copy keystores and truststores
    ./create_keystores_truststores.sh -n -v -p $PASSWORD -s $SALT -i $ITERATION

else 

    KEYSTORE_DIR="../ssl"
    SERVER_KEYSTORE="t590.usersys.redhat.com.jks"
    SERVER_TRUSTSTORE="truststore.jks"
    CLIENT_KEYSTORE="t590.usersys.redhat.com.jks"
    CLIENT_TRUSTSTORE="truststore.jks"

fi

cp $KEYSTORE_DIR/$SERVER_KEYSTORE $JBOSS_HOME/standalone/configuration
cp $KEYSTORE_DIR/$SERVER_TRUSTSTORE $JBOSS_HOME/standalone/configuration
cp $KEYSTORE_DIR/$CLIENT_KEYSTORE $JBOSS_HOME/standalone/configuration
cp $KEYSTORE_DIR/$CLIENT_TRUSTSTORE $JBOSS_HOME/standalone/configuration

cp $JBOSS_HOME/standalone/configuration/standalone.xml $JBOSS_HOME/standalone/configuration/standalone-custom.xml


$JBOSS_HOME/bin/add-user.sh -u admin -p admin
$JBOSS_HOME/bin/add-user.sh -a -u ejb -p ejb-123!

# prepare properties for the CLI script
[ -f ${PROPERTIES} ] && rm ${PROPERTIES}
echo "jboss.home=${JBOSS_HOME}" > ${PROPERTIES}
echo "credential.store.password.masked=`$JBOSS_HOME/bin/elytron-tool.sh mask --salt ${SALT} --iteration ${ITERATION} --secret ${PASSWORD}`" >> ${PROPERTIES}
echo "credential.store.filename=server-credential-store.jceks" >> ${PROPERTIES}
echo "server.keystore.filename=${SERVER_KEYSTORE}" >> ${PROPERTIES}
echo "server.keystore.password=${PASSWORD}" >> ${PROPERTIES}
echo "server.truststore.filename=${SERVER_TRUSTSTORE}" >> ${PROPERTIES}
echo "server.truststore.password=${PASSWORD}" >> ${PROPERTIES} 

# delete old logfiles
[ -d ${JBOSS_HOME}/standalone/log ] && rm -r ${JBOSS_HOME}/standalone/log

# delete exsisting credential-store if present
if [ -d ${JBOSS_HOME}/credential-stores ]; then
  rm -r ${JBOSS_HOME}/credential-stores
  
fi

# enable parameter resolving in jboss-cli
sed -i "s/<resolve-parameter-values>false<\/resolve-parameter-values>/\<resolve-parameter-values>true<\/resolve-parameter-values>/" $JBOSS_HOME/bin/jboss-cli.xml

$JBOSS_HOME/bin/jboss-cli.sh --file=${CLI_SCRIPT} --properties=${PROPERTIES}
